.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xpad
====

Defined in ``xtensor/xpad.hpp``

.. doxygenenum:: xt::pad_mode
   :project: xtensor

.. doxygenfunction:: xt::pad(E&& , const std::vector<std::vector<S>>&, pad_mode, V)
   :project: xtensor

.. doxygenfunction:: xt::pad(E&& , const std::vector<S>&, pad_mode, V)
   :project: xtensor

.. doxygenfunction:: xt::pad(E&& , S, pad_mode, V)
   :project: xtensor

.. doxygenfunction:: xt::tile(E&& , std::initializer_list<S>)
   :project: xtensor

.. doxygenfunction:: xt::tile(E&& , S)
   :project: xtensor
